==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/sources/v1beta1/ApiServerSourceSpecBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ApiServerSourceSpecBuilder extends ApiServerSourceSpecFluentImpl<ApiServerSourceSpecBuilder> implements VisitableBuilder<ApiServerSourceSpec,ApiServerSourceSpecBuilder> {

    ApiServerSourceSpecFluent<?> fluent;
    Boolean validationEnabled;

    public ApiServerSourceSpecBuilder() {
        this(true);
    }

    public ApiServerSourceSpecBuilder(Boolean validationEnabled) {
        this(new ApiServerSourceSpec(), validationEnabled);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ApiServerSourceSpec(), validationEnabled);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpecFluent<?> fluent,ApiServerSourceSpec instance) {
        this(fluent, instance, true);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpecFluent<?> fluent,ApiServerSourceSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCeOverrides(instance.getCeOverrides()); 
        fluent.withMode(instance.getMode()); 
        fluent.withOwner(instance.getOwner()); 
        fluent.withResources(instance.getResources()); 
        fluent.withServiceAccountName(instance.getServiceAccountName()); 
        fluent.withSink(instance.getSink()); 
        this.validationEnabled = validationEnabled; 
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpec instance) {
        this(instance,true);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCeOverrides(instance.getCeOverrides()); 
        this.withMode(instance.getMode()); 
        this.withOwner(instance.getOwner()); 
        this.withResources(instance.getResources()); 
        this.withServiceAccountName(instance.getServiceAccountName()); 
        this.withSink(instance.getSink()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.sources.v1beta1.EditableApiServerSourceSpec build() {
        EditableApiServerSourceSpec buildable = new EditableApiServerSourceSpec(fluent.getCeOverrides(),fluent.getMode(),fluent.getOwner(),fluent.getResources(),fluent.getServiceAccountName(),fluent.getSink());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ApiServerSourceSpecBuilder that = (ApiServerSourceSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/sources/v1beta1/ApiServerSourceSpecBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ApiServerSourceSpecBuilder extends ApiServerSourceSpecFluentImpl<ApiServerSourceSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<ApiServerSourceSpec,ApiServerSourceSpecBuilder> {

    ApiServerSourceSpecFluent<?> fluent;
    Boolean validationEnabled;

    public ApiServerSourceSpecBuilder() {
        this(true);
    }

    public ApiServerSourceSpecBuilder(Boolean validationEnabled) {
        this(new ApiServerSourceSpec(), validationEnabled);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ApiServerSourceSpec(), validationEnabled);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpecFluent<?> fluent,ApiServerSourceSpec instance) {
        this(fluent, instance, true);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpecFluent<?> fluent,ApiServerSourceSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCeOverrides(instance.getCeOverrides()); 
        fluent.withMode(instance.getMode()); 
        fluent.withOwner(instance.getOwner()); 
        fluent.withResources(instance.getResources()); 
        fluent.withServiceAccountName(instance.getServiceAccountName()); 
        fluent.withSink(instance.getSink()); 
        this.validationEnabled = validationEnabled; 
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpec instance) {
        this(instance,true);
    }

    public ApiServerSourceSpecBuilder(ApiServerSourceSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCeOverrides(instance.getCeOverrides()); 
        this.withMode(instance.getMode()); 
        this.withOwner(instance.getOwner()); 
        this.withResources(instance.getResources()); 
        this.withServiceAccountName(instance.getServiceAccountName()); 
        this.withSink(instance.getSink()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.sources.v1beta1.EditableApiServerSourceSpec build() {
        EditableApiServerSourceSpec buildable = new EditableApiServerSourceSpec(fluent.getCeOverrides(),fluent.getMode(),fluent.getOwner(),fluent.getResources(),fluent.getServiceAccountName(),fluent.getSink());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ApiServerSourceSpecBuilder that = (ApiServerSourceSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
